@@ -2,7 +2,7 @@ import unittest
 from libpysal.examples import load_example
 import geopandas as gpd
 import numpy as np
-from segregation.aspatial import DensityCorrectedDissim
+from segregation.singlegroup import DensityCorrectedDissim
 
 
 class Density_Corrected_Dissim_Tester(unittest.TestCase):
